package WebGUI::i18n::Spanish::Asset_WikiMaster;
use utf8;
our $I18N = {
  'Related Pages' => {
    'lastUpdated' => '1276812535',
    'message' => 'Páginas Relacionadas'
  },
  'Sub-keywords' => {
    'lastUpdated' => '1276812602',
    'message' => 'Palabras claves secundarias'
  },
  'actionN created' => {
    'lastUpdated' => '1253470425',
    'message' => 'Creada'
  },
  'actionN edited' => {
    'lastUpdated' => '1253470430',
    'message' => 'Editada'
  },
  'actionN protected' => {
    'lastUpdated' => '1253470445',
    'message' => 'Protegida'
  },
  'actionN trashed' => {
    'lastUpdated' => '1253470437',
    'message' => 'Eliminada'
  },
  'actionN unprotected' => {
    'lastUpdated' => '1253470453',
    'message' => 'Desprotegida'
  },
  'actionTaken' => {
    'lastUpdated' => '1253470418',
    'message' => 'Lo que ocurrió con esta página recientemente, típicamente "Editada" o "Creada"'
  },
  'addPageLabel' => {
    'lastUpdated' => '1253470463',
    'message' => 'Agregar una nueva página'
  },
  'addPageLabel variable' => {
    'lastUpdated' => '1253470479',
    'message' => 'La etiqueta del enlace para agregar página.'
  },
  'addPageUrl' => {
    'lastUpdated' => '1253470490',
    'message' => 'El URL que permite al usuario agregar una página al WiKi'
  },
  'allow attachments' => {
    'lastUpdated' => '1253470537',
    'message' => 'Adjuntos permitidos'
  },
  'allow attachments help' => {
    'lastUpdated' => '1253470524',
    'message' => '?'
  },
  'approval workflow' => {
    'lastUpdated' => '1253470552',
    'message' => 'Flujo de Trabajo para Aprobación'
  },
  'approval workflow description' => {
    'lastUpdated' => '1253470570',
    'message' => 'Seleccione el Flujo de Trabajo a seguir cada vez que se envía una página.'
  },
  'approvalWorkflow' => {
    'lastUpdated' => '1253470589',
    'message' => 'El ID del Flujo de Trabajo empleado para aprobar páginas en el WiKi.'
  },
  'asset description' => {
    'lastUpdated' => '1253470680',
    'message' => 'Un WiKi es un mecanismo colaborativo para publicar contenido. Tradicionalmente los WiKis and empleado un lenguaje de marcas particular para WiKis, pero eso tiene una complejidad similar a la de usar marcas HTML. Es por eso que los WiKis WebGUI utilizan un Editor Extendido para que los usuarios construyan su contenido con facilidad.'
  },
  'asset not committed' => {
    'lastUpdated' => '1253470698',
    'message' => 'Error! Debe consignar este WiKi antes de poder crear páginas en él.'
  },
  'assetName' => {
    'lastUpdated' => '1253470706',
    'message' => 'WiKi'
  },
  'by keyword formFooter' => {
    'lastUpdated' => '1276812683',
    'message' => 'Fragmento HTML para terminar el formulario de ingreso de palabras claves secundarias. Estará vacío a menos que el usuario tenga privilegios administrativos sobre este WiKi.'
  },
  'by keyword formHeader' => {
    'lastUpdated' => '1276812704',
    'message' => 'Fragmento HTML para comenzar el formulario de ingreso de palabras claves secundarias. Estará vacío a menos que el usuario tenga privilegios administrativos sobre este WiKi.'
  },
  'by keyword keyword' => {
    'lastUpdated' => '1276812788',
    'message' => 'La palabra clave solicitada.'
  },
  'by keyword keywordForm' => {
    'lastUpdated' => '1276812832',
    'message' => 'Fragmento HTML para el campo que permite ingresar palabras claves secundarias. Estará vacío a menos que el usuario tenga privilegios administrativos sobre este WiKi.'
  },
  'by keyword pagesLoop' => {
    'lastUpdated' => '1276812867',
    'message' => 'Un ciclo que itera sobre las páginas que contienen la palabra clave solicitada.'
  },
  'by keyword submitForm' => {
    'lastUpdated' => '1276812893',
    'message' => 'El botón para enviar el formulario de palabras claves secundarias.'
  },
  'by keyword synopsis' => {
    'lastUpdated' => '1276812920',
    'message' => 'El resumen sinóptico de la página.'
  },
  'by keyword template title' => {
    'lastUpdated' => '1276812962',
    'message' => 'Variables de Plantilla para Búsqueda por Palabras Clave'
  },
  'by keyword title' => {
    'lastUpdated' => '1276812972',
    'message' => 'El título de la página.'
  },
  'by keyword url' => {
    'lastUpdated' => '1276812981',
    'message' => 'El URL de la página.'
  },
  'byKeywordTemplateId hoverHelp' => {
    'lastUpdated' => '1253470732',
    'message' => 'Seleccione la Plantilla a utilizar para desplegar el listado de Páginas relacionadas con una palabra clave particular.'
  },
  'byKeywordTemplateId label' => {
    'lastUpdated' => '1253470749',
    'message' => 'Plantilla para Por Palabra Clave'
  },
  'canAddPages' => {
    'lastUpdated' => '1253470813',
    'message' => 'Variable canAddPages'
  },
  'canAddPages variable' => {
    'lastUpdated' => '1253470800',
    'message' => 'Un condicional que indica si el usuario puede agregar y editar páginas en el WiKi o no.'
  },
  'canAdminister' => {
    'lastUpdated' => '1253470826',
    'message' => 'Un condicional que indica si el usuario puede administrar el WiKi o no.'
  },
  'content filter' => {
    'lastUpdated' => '1253470840',
    'message' => '¿Aplicar Filtros de Contenido?'
  },
  'content filter description' => {
    'lastUpdated' => '1253470889',
    'message' => 'Indica si las páginas del WiKi deben procesarse a través del sistema de Control de Contenidos de WebGUI. Esto puede aprovecharse para crear marcas especiales que sirvan para incorporar estilos especiales en el contenido.'
  },
  'description' => {
    'lastUpdated' => '1253470933',
    'message' => 'La descripción para este WiKi, con enlaces automáticos hacia cualquier título o URL presentes en él.'
  },
  'filter code' => {
    'lastUpdated' => '1253470990',
    'message' => 'Filtrado de HTML'
  },
  'filter code description' => {
    'lastUpdated' => '1253470979',
    'message' => 'Establece el nivel de filtrado de HTML aplicado sobre las entradas del WiKi.'
  },
  'filterCode' => {
    'lastUpdated' => '1253471011',
    'message' => 'Una cadena que especifica el nivel de filtrado de contenido.'
  },
  'front page template title' => {
    'lastUpdated' => '1253471025',
    'message' => 'Wiki, Variables de Plantilla para Página Principal'
  },
  'frontPageTemplateId' => {
    'lastUpdated' => '1253471053',
    'message' => 'El ID de la Plantilla empleada para desplegar la Página Principal del WiKi.'
  },
  'frontPageTemplateId hoverHelp' => {
    'lastUpdated' => '1253471069',
    'message' => 'Indique la Plantilla a utilizar para desplegar la Página Principal del WiKi.'
  },
  'frontPageTemplateId label' => {
    'lastUpdated' => '1253471077',
    'message' => 'Plantilla para Página Principal'
  },
  'func addPage link text' => {
    'lastUpdated' => '1253471084',
    'message' => 'Agregar una página'
  },
  'func listPages link text' => {
    'lastUpdated' => '1253471092',
    'message' => 'Listar todas las páginas'
  },
  'func recentChanges link text' => {
    'lastUpdated' => '1253471099',
    'message' => 'Mostrar cambios recientes'
  },
  'func search link text' => {
    'lastUpdated' => '1253471108',
    'message' => 'Buscar en las páginas'
  },
  'func view link text' => {
    'lastUpdated' => '1253471118',
    'message' => 'Regresar a la Principal'
  },
  'groupToAdminister' => {
    'lastUpdated' => '1253471138',
    'message' => 'El ID del Grupo que puede administrar el WiKi o editar cualquier Página.'
  },
  'groupToAdminister hoverHelp' => {
    'lastUpdated' => '1253471313',
    'message' => 'Seleccione un Grupo de usuarios que será capaz de realizar labores administrativas en las páginas de este WiKi. Esto incluye eliminar páginas y revisiones de páginas, así como proteger o desproteger páginas.'
  },
  'groupToAdminister label' => {
    'lastUpdated' => '1253471322',
    'message' => 'Grupo de Administradores'
  },
  'groupToEditPages' => {
    'lastUpdated' => '1253471334',
    'message' => 'El ID del Grupo que puede editar Páginas.'
  },
  'groupToEditPages hoverHelp' => {
    'lastUpdated' => '1253471369',
    'message' => 'Seleccione el Grupo de usuarios que puede editar Páginas en este WiKi. No podrán eliminar páginas, no podrán eliminar revisiones ni editar páginas protegidas.'
  },
  'groupToEditPages label' => {
    'lastUpdated' => '1253471390',
    'message' => 'Grupo de Editores'
  },
  'help isSubscribed' => {
    'lastUpdated' => '1253710914',
    'message' => 'Un condicional que indica si el usuario está suscrito al WiKi'
  },
  'help subscribeUrl' => {
    'lastUpdated' => '1253710926',
    'message' => 'El URL para suscribirse al WiKi.'
  },
  'help unsubscribeUrl' => {
    'lastUpdated' => '1253710952',
    'message' => 'El URL para desuscribirse del WiKi.'
  },
  'indent_loop' => {
    'lastUpdated' => '1272376205',
    'message' => 'Un ciclo que itera una vez por cada nivel.'
  },
  'keyword descendants' => {
    'lastUpdated' => '1276813017',
    'message' => 'El número de páginas en el WiKi que están marcadas con esta palabra clave, y todas las palabras claves secundarias asociadas.'
  },
  'keyword indent' => {
    'lastUpdated' => '1272376219',
    'message' => 'El iterador del ciclo indent_loop.'
  },
  'keyword isTopLevel' => {
    'lastUpdated' => '1276813082',
    'message' => 'Un condicional que indica si la palabra clave está presente en la página indicada. Si se trata de la Página Principal del WiKi, solamente toma en cuenta las palabras clave globales. Para una página de palabras clave, solamente toma en cuenta las palabras clave secundarias.'
  },
  'keyword level' => {
    'lastUpdated' => '1272376249',
    'message' => 'La profundidad de esta palabra clave. Las palabras clave en el nivel superior del WiKi tienen nivel 0.'
  },
  'keyword page variables' => {
    'lastUpdated' => '1276813100',
    'message' => 'Variables para Página de Palabras Clave'
  },
  'keyword title' => {
    'lastUpdated' => '1272376257',
    'message' => 'El título para esta palabra clave.'
  },
  'keyword url' => {
    'lastUpdated' => '1272376276',
    'message' => 'El URL hacia la página para la palabra clave. Si no existe tal página, la variable estará vacía.'
  },
  'keywords_loop' => {
    'lastUpdated' => '1272376318',
    'message' => 'Un ciclo que contiene las palabras clave en el tope, enlaces a sus palabras claves y todas las sub-páginas.'
  },
  'listPages title' => {
    'lastUpdated' => '1253471396',
    'message' => 'Lista de Páginas'
  },
  'max image size' => {
    'lastUpdated' => '1253471411',
    'message' => 'Tamaño Máximo de Imágenes'
  },
  'max image size help' => {
    'lastUpdated' => '1253471485',
    'message' => 'Establece el tamaño máximo para imágenes adjuntas al WiKi. Si se establece en 0 se empleará el tamaño presente en la configuración global de WebGUI. Así mismo, cambiar el valor <strong>no</strong> tiene efecto retroactivo, siendo necesario volver a salvar todas las páginas existentes para redimensionar las imágenes si fuera necesario.'
  },
  'maxImageSize' => {
    'lastUpdated' => '1253471500',
    'message' => 'El tamaño máximos para imágenes adjuntas al WiKi.'
  },
  'most popular template body' => {
    'lastUpdated' => '1253471524',
    'message' => 'Estas Variables están disponibles en la Plantilla para desplegar las Páginas Populares del WiKi.'
  },
  'most popular template title' => {
    'lastUpdated' => '1253471543',
    'message' => 'Wiki, Plantilla para Páginas Populares'
  },
  'most popular title' => {
    'lastUpdated' => '1253471556',
    'message' => 'El título de la página del conjunto de Páginas Populares.'
  },
  'most popular title variable' => {
    'lastUpdated' => '1253471572',
    'message' => 'El título para la Plantilla de Páginas Populares'
  },
  'most popular url' => {
    'lastUpdated' => '1253471584',
    'message' => 'El URL a la Página con el conjunto de Páginas Populares.'
  },
  'most popular variables title' => {
    'lastUpdated' => '1253471600',
    'message' => 'Wiki, Variables para Plantilla de Páginas Populares'
  },
  'mostPopular' => {
    'lastUpdated' => '1253471627',
    'message' => 'Un ciclo que itera sobre las Páginas Populares. El número de páginas en el ciclo depende de los parámetors del WiKi.'
  },
  'mostPopularCount hoverHelp' => {
    'lastUpdated' => '1253471656',
    'message' => 'El número máximo de enlaces a Páginas Populares que deben incluirse en la selección de Páginas Populares.'
  },
  'mostPopularCount label' => {
    'lastUpdated' => '1253472298',
    'message' => 'Páginas Populares a Listar'
  },
  'mostPopularCountFront hoverHelp' => {
    'lastUpdated' => '1253471699',
    'message' => 'Número máximo de enlaces a Páginas Populares a incluir en la Página Principal.'
  },
  'mostPopularCountFront label' => {
    'lastUpdated' => '1253472313',
    'message' => 'Páginas Populares a Listar en Página Principal'
  },
  'mostPopularLabel' => {
    'lastUpdated' => '1253471755',
    'message' => 'Más Popular'
  },
  'mostPopularLabel variable' => {
    'lastUpdated' => '1253471769',
    'message' => 'La etiqueta del enlace a la Página más Popular.'
  },
  'mostPopularTemplateId' => {
    'lastUpdated' => '1253471786',
    'message' => 'El ID de la Plantilla a utilizar para desplegar la lista de Páginas Populares en el WiKi.'
  },
  'mostPopularTemplateId hoverHelp' => {
    'lastUpdated' => '1253471805',
    'message' => 'Seleccione la Plantilla a utilizar para desplegar el listado de Páginas Populares.'
  },
  'mostPopularTemplateId label' => {
    'lastUpdated' => '1253471813',
    'message' => 'Plantilla para Páginas Populares'
  },
  'mostPopularUrl' => {
    'lastUpdated' => '1253471831',
    'message' => 'El URL hacia la página con Páginas Populares del WiKi.'
  },
  'notWhatYouWanted variable' => {
    'lastUpdated' => '1253471854',
    'message' => 'La etiqueta para preguntar al usuario si no pudo encontrar lo que buscaba.'
  },
  'notWhatYouWantedLabel' => {
    'lastUpdated' => '1253471868',
    'message' => '¿No encontró lo que buscaba?'
  },
  'nothingFoundLabel' => {
    'lastUpdated' => '1253471883',
    'message' => 'Su búsqueda no produjo resultados.'
  },
  'nothingFoundLabel variable' => {
    'lastUpdated' => '1253471898',
    'message' => 'Una etiqueta para indicar al usuario que su búsqueda no produjo resultados.'
  },
  'pageEditTemplateId' => {
    'lastUpdated' => '1253471919',
    'message' => 'El ID de la Plantilla utilizada para desplegar la pantalla de edición de Páginas del WiKi.'
  },
  'pageEditTemplateId hoverHelp' => {
    'lastUpdated' => '1253471948',
    'message' => 'Seleccione la Plantilla utilizada para desplegar la pantalla empleada para editar Páginas.'
  },
  'pageEditTemplateId label' => {
    'lastUpdated' => '1253471956',
    'message' => 'Plantilla para Editar Páginas'
  },
  'pageHistoryTemplateId' => {
    'lastUpdated' => '1253471986',
    'message' => 'El ID de la Plantilla empleada para desplegar la lista de cambios para una Página particular en el WiKi.'
  },
  'pageHistoryTemplateId hoverHelp' => {
    'lastUpdated' => '1253472004',
    'message' => 'Seleccione la Plantilla a utilizar para desplegar la historia de una Página.'
  },
  'pageHistoryTemplateId label' => {
    'lastUpdated' => '1253472014',
    'message' => 'Plantilla para Historia de una Página'
  },
  'pageTemplateId' => {
    'lastUpdated' => '1253472030',
    'message' => 'El ID de la Plantilla empleada para desplegar las Páginas del WiKi.'
  },
  'pageTemplateId hoverHelp' => {
    'lastUpdated' => '1253472042',
    'message' => 'Seleccione la Plantilla empleada para desplegar las Páginas del WiKi.'
  },
  'pageTemplateId label' => {
    'lastUpdated' => '1253472049',
    'message' => 'Plantilla para Páginas'
  },
  'performSearch' => {
    'lastUpdated' => '1253472064',
    'message' => 'La constante "1".'
  },
  'recent changes date' => {
    'lastUpdated' => '1253472079',
    'message' => 'Fecha en la cual la página fue cambiada.'
  },
  'recent changes is available' => {
    'lastUpdated' => '1253472098',
    'message' => 'Un condicional que indica si la página está disponible para ser vista o si está en la basura o portapapeles.'
  },
  'recent changes restore url' => {
    'lastUpdated' => '1253472116',
    'message' => 'Un URL para restablecer esta página desde la papelera o portapapeles.'
  },
  'recent changes template body' => {
    'lastUpdated' => '1253472143',
    'message' => 'Estas variables están disponibles en la Plantilla empleada para desplegar la página de Cambios Recientes en el WiKi.'
  },
  'recent changes template title' => {
    'lastUpdated' => '1253472154',
    'message' => 'WiKi, Plantilla para Cambios Recientes'
  },
  'recent changes title' => {
    'lastUpdated' => '1253472177',
    'message' => 'El título Plantilla para Cambios Recientes.'
  },
  'recent changes url' => {
    'lastUpdated' => '1253472188',
    'message' => 'El URL hacia la página de Cambios Recientes.'
  },
  'recent changes username' => {
    'lastUpdated' => '1253472203',
    'message' => 'El nombre del usuario que realizó el cambio más reciente a la Página.'
  },
  'recent changes variables title' => {
    'lastUpdated' => '1253472220',
    'message' => 'WiKi, Variables de Plantilla para Cambios Recientes'
  },
  'recentChanges' => {
    'lastUpdated' => '1253472247',
    'message' => 'Un ciclo que contiene información acerca de las Páginas que han sido cambiadas recientemente. La cantidad de páginas en el ciclo depende de la configuración del WiKi.'
  },
  'recentChangesCount hoverHelp' => {
    'lastUpdated' => '1253472267',
    'message' => 'El número máximo de cambios a listar en la Página de Cambios Recientes.'
  },
  'recentChangesCount label' => {
    'lastUpdated' => '1253472280',
    'message' => 'Cambios Recientes a Listar'
  },
  'recentChangesCountFront hoverHelp' => {
    'lastUpdated' => '1253472330',
    'message' => 'El número máximo de Cambios Recientes a listar en la Página Principal.'
  },
  'recentChangesCountFront label' => {
    'lastUpdated' => '1253472341',
    'message' => 'Cambios Recientes a Listar en Página Principal'
  },
  'recentChangesLabel' => {
    'lastUpdated' => '1253472348',
    'message' => 'Cambios Recientes'
  },
  'recentChangesLabel variable' => {
    'lastUpdated' => '1253472358',
    'message' => 'La etiqueta para el enlace a Cambios Recientes'
  },
  'recentChangesTemplateId' => {
    'lastUpdated' => '1253472375',
    'message' => 'El ID de la Plantilla empleada para desplegar la lista de Cambios Recientes en el WiKi.'
  },
  'recentChangesTemplateId hoverHelp' => {
    'lastUpdated' => '1253472389',
    'message' => 'Seleccione la Plantilla a emplear para desplegar la lista de Cambios Recientes.'
  },
  'recentChangesTemplateId label' => {
    'lastUpdated' => '1253472398',
    'message' => 'Plantilla para Cambios Recientes'
  },
  'recentChangesUrl' => {
    'lastUpdated' => '1253472421',
    'message' => 'El URL para llevar al usuario a la pantall con la lista de Cambios Recientes.'
  },
  'restoreLabel' => {
    'lastUpdated' => '1253472427',
    'message' => 'Restaurar'
  },
  'resultsLabel' => {
    'lastUpdated' => '1253472432',
    'message' => 'Resultados'
  },
  'resultsLabel variable' => {
    'lastUpdated' => '1253472447',
    'message' => 'La etiqueta para el título de la página de resultados de búsqueda.'
  },
  'richEditor' => {
    'lastUpdated' => '1253472461',
    'message' => 'El ID del Editor Extendido a utilizar para editar las páginas del WiKi'
  },
  'richEditor hoverHelp' => {
    'lastUpdated' => '1253472476',
    'message' => 'Seleccione el Editor Extendido a emplear para la edición de páginas en el WiKi.'
  },
  'richEditor label' => {
    'lastUpdated' => '1253472483',
    'message' => 'Editor Extendido'
  },
  'search box variables title' => {
    'lastUpdated' => '1253472498',
    'message' => 'WiKi, Variables para Forma de Búsqueda'
  },
  'search template body' => {
    'lastUpdated' => '1253472523',
    'message' => 'Estas Variables están disponibles en la Plantilla empleada para desplegar la Página de Búsqueda en el WiKi.'
  },
  'search template title' => {
    'lastUpdated' => '1253472532',
    'message' => 'WiKi, Plantilla para Búsqueda'
  },
  'search title variable' => {
    'lastUpdated' => '1253472547',
    'message' => 'El título de la Página retornada como resultado de la búsqueda.'
  },
  'search url variable' => {
    'lastUpdated' => '1253472561',
    'message' => 'El URL de la Página retornada como resultado de búsqueda.'
  },
  'searchFormFooter' => {
    'lastUpdated' => '1253472576',
    'message' => 'Fragmento HTML para terminar el formulario de búsqueda.'
  },
  'searchFormHeader' => {
    'lastUpdated' => '1253472586',
    'message' => 'Fragmento HTML para iniciar el formulario de búsqueda.'
  },
  'searchLabel' => {
    'lastUpdated' => '1253472591',
    'message' => 'Buscar'
  },
  'searchLabel variable' => {
    'lastUpdated' => '1253472609',
    'message' => 'La etiqueta para el enlace a la página de búsqueda.'
  },
  'searchQuery' => {
    'lastUpdated' => '1253472631',
    'message' => 'Fragmento HTML para la caja de búsqueda en la cual escribir los términos a buscar.'
  },
  'searchResults' => {
    'lastUpdated' => '1253472648',
    'message' => 'Un ciclo que contiene todos los resultados de la búsqueda del usuario, posiblemente vacío.'
  },
  'searchSubmit' => {
    'lastUpdated' => '1253472670',
    'message' => 'El botón para ejecutar la búsqueda.'
  },
  'searchTemplateId' => {
    'lastUpdated' => '1253472685',
    'message' => 'El ID de la Plantilla empleada para desplegar la Página de Búsqueda.'
  },
  'searchTemplateId hoverHelp' => {
    'lastUpdated' => '1253472706',
    'message' => 'Seleccione la Plantilla a emplear para desplegar los resultados de la búsqueda.'
  },
  'searchTemplateId label' => {
    'lastUpdated' => '1253472727',
    'message' => 'Plantilla para Búsqueda'
  },
  'searchUrl' => {
    'lastUpdated' => '1253472738',
    'message' => 'El URL para llevar al usuario a la Página de Búsqueda.'
  },
  'subscribe' => {
    'lastUpdated' => '1253710965',
    'message' => 'Suscribirse'
  },
  'thumbnail size' => {
    'lastUpdated' => '1253472749',
    'message' => 'Tamaño de las Miniaturas'
  },
  'thumbnail size help' => {
    'lastUpdated' => '1253472816',
    'message' => 'Establece el tamaño de las imágenes miniatura para este WiKi. Si se establece en 0, se utilizará el tamaño definido en la configuración principal de WebGUI. Si se cambia, <strong>no</strong> tiene efectos retroactivos, siendo necesario volver a salvar todas las páginas para redimensionar las imágenes.'
  },
  'thumbnailSize' => {
    'lastUpdated' => '1253472827',
    'message' => 'El tamaño de las miniaturas para este WiKi.'
  },
  'top level keywords' => {
    'lastUpdated' => '1272376336',
    'message' => 'Palabras Clave Principales'
  },
  'top level keywords description' => {
    'lastUpdated' => '1272376354',
    'message' => 'Estas palabras clave proveen la raíz para desplegar la jerarquía de palabras clave.'
  },
  'unsubscribe' => {
    'lastUpdated' => '1253711856',
    'message' => 'Desuscribirse'
  },
  'useContentFilter' => {
    'lastUpdated' => '1253472853',
    'message' => 'Un condicional que indica si sobre este WiKi se aplican filtros de contenido o no.'
  },
  'wiki master asset variables title' => {
    'lastUpdated' => '1253472868',
    'message' => 'WiKi, Variables del Activo'
  },
  'wikiHomeLabel' => {
    'lastUpdated' => '1253472926',
    'message' => 'Página Principal del WiKi'
  },
  'wikiHomeLabel variable' => {
    'lastUpdated' => '1253472903',
    'message' => 'La etiqueta para el enlace que lleva a la Página Principal del WiKi'
  },
  'wikiHomeUrl' => {
    'lastUpdated' => '1253472915',
    'message' => 'El URL que lleva a la Página Principal del WiKi.'
  }
}
;

1;
